@@ -23,14 +23,21 @@ public class HasSuffixPatternStep implements PatternStep {
     private final String suffix;
     private final boolean caseSensitive;
     private final int suffixLength;
+    private final int prefixLength;
 
     public HasSuffixPatternStep(String suffix, boolean caseSensitive) {
+        this(suffix, caseSensitive, 0);
+    }
+
+    // Used by HasPrefixAndSuffixPatternStep to ensure the suffix isn't matching any part of the prefix.
+    HasSuffixPatternStep(String suffix, boolean caseSensitive, int prefixLength) {
         this.suffix = suffix;
         suffixLength = suffix.length();
         this.caseSensitive = caseSensitive;
+        this.prefixLength = prefixLength;
     }
 
     public boolean matches(String candidate) {
-        return candidate.regionMatches(!caseSensitive, candidate.length() - suffixLength, suffix, 0, suffixLength);
+        return prefixLength + suffixLength <= candidate.length() && candidate.regionMatches(!caseSensitive, candidate.length() - suffixLength, suffix, 0, suffixLength);
     }
 }
