@@ -38,7 +38,20 @@ import javax.inject.Inject;
 @Incubating
 public class ModelReport extends DefaultTask {
 
+    /**
+     * The report format.
+     * <ul>
+     *     <li><i>full</i> (default value) will show details about types, rules and creators</li>
+     *     <li><i>short</i> will only show nodes and their values</li>
+     * </ul>
+     */
+    public enum Format {
+        FULL,
+        SHORT
+    }
+
     private boolean showHidden;
+    private Format format = Format.FULL;
 
     @Option(option = "showHidden", description = "Show hidden model elements.")
     public void setShowHidden(boolean showHidden) {
@@ -49,6 +62,15 @@ public class ModelReport extends DefaultTask {
         return showHidden;
     }
 
+    @Option(option = "format", description = "Output format (full, short)")
+    public void setFormat(String format) {
+        this.format = Format.valueOf(format.toUpperCase());
+    }
+
+    public Format getFormat() {
+        return format;
+    }
+
     @Inject
     protected StyledTextOutputFactory getTextOutputFactory() {
         throw new UnsupportedOperationException();
@@ -63,7 +85,7 @@ public class ModelReport extends DefaultTask {
     public void report() {
         Project project = getProject();
         StyledTextOutput textOutput = getTextOutputFactory().create(ModelReport.class);
-        ModelNodeRenderer renderer = new ModelNodeRenderer(isShowHidden());
+        ModelNodeRenderer renderer = new ModelNodeRenderer(isShowHidden(), getFormat());
 
         TextModelReportRenderer textModelReportRenderer = new TextModelReportRenderer(renderer);
 
