@@ -28,6 +28,8 @@ public enum GeneratedIdeaScope {
     PROVIDED_TEST("PROVIDED", "TEST"),
     PROVIDED("PROVIDED"),
     COMPILE("COMPILE"),
+    RUNTIME_COMPILE_CLASSPATH("PROVIDED", "RUNTIME"),
+    RUNTIME_TEST_COMPILE_CLASSPATH("PROVIDED", "TEST"),
     RUNTIME_TEST("RUNTIME", "TEST"),
     RUNTIME("RUNTIME"),
     TEST("TEST"),
