@@ -41,17 +41,24 @@ import static org.gradle.model.internal.core.ModelNode.State.*;
 public class DefaultModelRegistry implements ModelRegistryInternal {
     private static final Logger LOGGER = LoggerFactory.getLogger(DefaultModelRegistry.class);
 
+    private final String projectPath;
     private final ModelGraph modelGraph;
     private final RuleBindings ruleBindings;
     private final ModelRuleExtractor ruleExtractor;
     private final Set<RuleBinder> unboundRules = Sets.newIdentityHashSet();
 
-    public DefaultModelRegistry(ModelRuleExtractor ruleExtractor) {
+    public DefaultModelRegistry(ModelRuleExtractor ruleExtractor, String projectPath) {
         this.ruleExtractor = ruleExtractor;
+        this.projectPath = projectPath;
         ModelRegistration rootRegistration = ModelRegistrations.of(ModelPath.ROOT).descriptor("<root>").withProjection(EmptyModelProjection.INSTANCE).build();
         modelGraph = new ModelGraph(new ModelElementNode(this, rootRegistration, null));
-        modelGraph.getRoot().setState(Created);
         ruleBindings = new RuleBindings();
+        transition(modelGraph.getRoot(), Created, false);
+    }
+
+    @Override
+    public String getProjectPath() {
+        return projectPath;
     }
 
     @Override
@@ -70,7 +77,7 @@ public class DefaultModelRegistry implements ModelRegistryInternal {
     public void registerNode(ModelNodeInternal node, Multimap<ModelActionRole, ? extends ModelAction> actions) {
         // Disabled before 2.3 release due to not wanting to validate task names (which may contain invalid chars), at least not yet
         // ModelPath.validateName(name);
-
+        LOGGER.debug("Project {} - Registering model element '{}' (hidden = {})", projectPath, node.getPath(), node.isHidden());
         addRuleBindings(node, actions);
         modelGraph.add(node);
         ruleBindings.nodeCreated(node);
@@ -272,7 +279,7 @@ public class DefaultModelRegistry implements ModelRegistryInternal {
         boolean newInputsBound = true;
         while (!unboundRules.isEmpty() && newInputsBound) {
             newInputsBound = false;
-            RuleBinder[] unboundBinders = unboundRules.toArray(new RuleBinder[unboundRules.size()]);
+            RuleBinder[] unboundBinders = unboundRules.toArray(new RuleBinder[0]);
             for (RuleBinder binder : unboundBinders) {
                 transitionTo(graph, new TryBindInputs(binder));
                 newInputsBound = newInputsBound || binder.isBound();
@@ -327,7 +334,7 @@ public class DefaultModelRegistry implements ModelRegistryInternal {
      */
     // TODO - reuse graph, discard state once not required
     private void transitionTo(GoalGraph goalGraph, ModelGoal targetGoal) {
-        LinkedList<ModelGoal> queue = new LinkedList<ModelGoal>();
+        Deque<ModelGoal> queue = new ArrayDeque<ModelGoal>();
         queue.add(targetGoal);
         List<ModelGoal> newDependencies = new ArrayList<ModelGoal>();
         while (!queue.isEmpty()) {
@@ -370,12 +377,12 @@ public class DefaultModelRegistry implements ModelRegistryInternal {
                     queue.addFirst(dependency);
                     continue;
                 }
-                throw ruleCycle(dependency, queue);
+                throw ruleCycle(dependency, Lists.newArrayList(queue));
             }
         }
     }
 
-    private ConfigurationCycleException ruleCycle(ModelGoal brokenGoal, LinkedList<ModelGoal> queue) {
+    private ConfigurationCycleException ruleCycle(ModelGoal brokenGoal, List<ModelGoal> queue) {
         List<String> path = new ArrayList<String>();
         int pos = queue.indexOf(brokenGoal);
         ListIterator<ModelGoal> iterator = queue.listIterator(pos + 1);
@@ -412,7 +419,7 @@ public class DefaultModelRegistry implements ModelRegistryInternal {
         ModelPath path = node.getPath();
         ModelNode.State state = node.getState();
 
-        LOGGER.debug("Transitioning model element '{}' from state {} to {}", path, state.name(), desired.name());
+        LOGGER.debug("Project {} - Transitioning model element '{}' from state {} to {}", projectPath, path, state.name(), desired.name());
 
         if (desired.ordinal() < state.ordinal()) {
             if (laterOk) {
@@ -437,7 +444,7 @@ public class DefaultModelRegistry implements ModelRegistryInternal {
         final ModelAction mutator = boundMutator.getAction();
         ModelRuleDescriptor descriptor = mutator.getDescriptor();
 
-        LOGGER.debug("Mutating {} using {}", node.getPath(), descriptor);
+        LOGGER.debug("Project {} - Mutating {} using {}", projectPath, node.getPath(), descriptor);
 
         try {
             RuleContext.run(descriptor, new Runnable() {
@@ -688,7 +695,7 @@ public class DefaultModelRegistry implements ModelRegistryInternal {
             if (!node.getState().equals(getTargetState().previous())) {
                 throw new IllegalStateException(String.format("Cannot transition model element '%s' to state %s as it is already at state %s.", node.getPath(), getTargetState(), node.getState()));
             }
-            LOGGER.debug("Transitioning model element '{}' to state {}.", node.getPath(), getTargetState().name());
+            LOGGER.debug("Project {} - Transitioning model element '{}' to state {}.", projectPath, node.getPath(), getTargetState().name());
             node.setState(getTargetState());
         }
 
@@ -1141,7 +1148,7 @@ public class DefaultModelRegistry implements ModelRegistryInternal {
 
         @Override
         void apply() {
-            LOGGER.debug("Running model element '{}' rule action {}", getPath(), binder.getDescriptor());
+            LOGGER.debug("Project {} - Running model element '{}' rule action {}", projectPath, getPath(), binder.getDescriptor());
             fireAction(binder);
             node.notifyFired(binder);
         }
