@@ -21,8 +21,8 @@ import com.google.common.collect.Sets;
 import org.gradle.api.Nullable;
 import org.gradle.api.Task;
 import org.gradle.api.file.FileCollection;
-import org.gradle.api.internal.AbstractBuildableModelElement;
-import org.gradle.api.internal.file.FileResolver;
+import org.gradle.api.internal.AbstractBuildableComponentSpec;
+import org.gradle.api.internal.file.SourceDirectorySetFactory;
 import org.gradle.api.tasks.TaskDependency;
 import org.gradle.jvm.internal.JvmAssembly;
 import org.gradle.language.base.LanguageSourceSet;
@@ -35,6 +35,7 @@ import org.gradle.language.scala.internal.DefaultScalaLanguageSourceSet;
 import org.gradle.language.scala.internal.ScalaJvmAssembly;
 import org.gradle.platform.base.binary.BaseBinarySpec;
 import org.gradle.platform.base.internal.BinaryBuildAbility;
+import org.gradle.platform.base.internal.ComponentSpecIdentifier;
 import org.gradle.platform.base.internal.ToolSearchBuildAbility;
 import org.gradle.play.JvmClasses;
 import org.gradle.play.PlayApplicationSpec;
@@ -48,9 +49,9 @@ import java.util.Set;
 
 import static org.gradle.util.CollectionUtils.single;
 
-public class DefaultPlayApplicationBinarySpec extends BaseBinarySpec implements PlayApplicationBinarySpecInternal {
-    private final DefaultScalaJvmAssembly jvmAssembly = new DefaultScalaJvmAssembly();
-    private final PublicAssets assets = new DefaultPublicAssets();
+public class DefaultPlayApplicationBinarySpec extends BaseBinarySpec  implements PlayApplicationBinarySpecInternal {
+    private final DefaultScalaJvmAssembly jvmAssembly = new DefaultScalaJvmAssembly(getIdentifier().child("assembly"));
+    private final PublicAssets assets = new DefaultPublicAssets(getIdentifier().child("publicAssets"));
     private Map<LanguageSourceSet, ScalaLanguageSourceSet> generatedScala = Maps.newHashMap();
     private Map<LanguageSourceSet, JavaScriptSourceSet> generatedJavaScript = Maps.newHashMap();
     private PlayPlatform platform;
@@ -69,48 +70,59 @@ public class DefaultPlayApplicationBinarySpec extends BaseBinarySpec implements
         return getComponentAs(PlayApplicationSpec.class);
     }
 
+    @Override
     public PlayPlatform getTargetPlatform() {
         return platform;
     }
 
+    @Override
     public PlayToolChainInternal getToolChain() {
         return toolChain;
     }
 
+    @Override
     public ScalaJvmAssembly getAssembly() {
         return jvmAssembly;
     }
 
+    @Override
     public File getJarFile() {
         return jarFile;
     }
 
+    @Override
     public void setTargetPlatform(PlayPlatform platform) {
         this.platform = platform;
         jvmAssembly.setTargetPlatform(platform.getJavaPlatform());
         jvmAssembly.setScalaPlatform(platform.getScalaPlatform());
     }
 
+    @Override
     public void setToolChain(PlayToolChainInternal toolChain) {
         this.toolChain = toolChain;
     }
 
+    @Override
     public void setJarFile(File file) {
         this.jarFile = file;
     }
 
+    @Override
     public File getAssetsJarFile() {
         return assetsJarFile;
     }
 
+    @Override
     public void setAssetsJarFile(File assetsJarFile) {
         this.assetsJarFile = assetsJarFile;
     }
 
+    @Override
     public JvmClasses getClasses() {
         return new JvmClassesAdapter(jvmAssembly);
     }
 
+    @Override
     public PublicAssets getAssets() {
         return assets;
     }
@@ -121,10 +133,10 @@ public class DefaultPlayApplicationBinarySpec extends BaseBinarySpec implements
     }
 
     @Override
-    public void addGeneratedScala(LanguageSourceSet input, FileResolver fileResolver) {
+    public void addGeneratedScala(LanguageSourceSet input, SourceDirectorySetFactory sourceDirectorySetFactory) {
         String lssName = String.format("%sScalaSources", input.getName());
-        // TODO:DAZ To get rid of this, we need a `FunctionalSourceSet` instance here, and that's surprisingly difficult to get.
-        ScalaLanguageSourceSet generatedScalaSources = BaseLanguageSourceSet.create(ScalaLanguageSourceSet.class, DefaultScalaLanguageSourceSet.class, lssName, getName(), fileResolver);
+        // TODO: To get rid of this, we need a `FunctionalSourceSet` instance here, and that's surprisingly difficult to get.
+        ScalaLanguageSourceSet generatedScalaSources = BaseLanguageSourceSet.create(ScalaLanguageSourceSet.class, DefaultScalaLanguageSourceSet.class, getIdentifier().child(lssName), sourceDirectorySetFactory);
         generatedScalaSources.builtBy();
         generatedScala.put(input, generatedScalaSources);
     }
@@ -135,9 +147,9 @@ public class DefaultPlayApplicationBinarySpec extends BaseBinarySpec implements
     }
 
     @Override
-    public void addGeneratedJavaScript(LanguageSourceSet input, FileResolver fileResolver) {
+    public void addGeneratedJavaScript(LanguageSourceSet input, SourceDirectorySetFactory sourceDirectorySetFactory) {
         String lssName = String.format("%sJavaScript", input.getName());
-        JavaScriptSourceSet javaScript = BaseLanguageSourceSet.create(JavaScriptSourceSet.class, DefaultJavaScriptSourceSet.class, lssName, getName(), fileResolver);
+        JavaScriptSourceSet javaScript = BaseLanguageSourceSet.create(JavaScriptSourceSet.class, DefaultJavaScriptSourceSet.class, getIdentifier().child(lssName), sourceDirectorySetFactory);
         javaScript.builtBy();
         generatedJavaScript.put(input, javaScript);
     }
@@ -170,51 +182,81 @@ public class DefaultPlayApplicationBinarySpec extends BaseBinarySpec implements
             this.jvmAssembly = jvmAssembly;
         }
 
+        @Override
+        public String getDisplayName() {
+            return jvmAssembly.getDisplayName();
+        }
+
+        @Override
+        public String getProjectPath() {
+            return jvmAssembly.getProjectPath();
+        }
+
+        @Override
+        public String getName() {
+            return jvmAssembly.getName();
+        }
+
+        @Override
         public File getClassesDir() {
             return single(jvmAssembly.getClassDirectories());
         }
 
+        @Override
         public void setClassesDir(File classesDir) {
             replaceSingleDirectory(jvmAssembly.getClassDirectories(), classesDir);
         }
 
+        @Override
         public Set<File> getResourceDirs() {
             return jvmAssembly.getResourceDirectories();
         }
 
+        @Override
         public void addResourceDir(File resourceDir) {
             jvmAssembly.getResourceDirectories().add(resourceDir);
         }
 
+        @Override
         public void builtBy(Object... tasks) {
             jvmAssembly.builtBy(tasks);
         }
 
+        @Override
         @Nullable
         public Task getBuildTask() {
             return jvmAssembly.getBuildTask();
         }
 
+        @Override
         public void setBuildTask(Task lifecycleTask) {
             jvmAssembly.setBuildTask(lifecycleTask);
         }
 
+        @Override
         public boolean hasBuildDependencies() {
             return jvmAssembly.hasBuildDependencies();
         }
 
+        @Override
         public TaskDependency getBuildDependencies() {
             return jvmAssembly.getBuildDependencies();
         }
     }
 
-    private static class DefaultPublicAssets extends AbstractBuildableModelElement implements PublicAssets {
+    private static class DefaultPublicAssets extends AbstractBuildableComponentSpec implements PublicAssets {
         private Set<File> resourceDirs = Sets.newLinkedHashSet();
 
+        public DefaultPublicAssets(ComponentSpecIdentifier identifier) {
+            super(identifier, PublicAssets.class);
+        }
+
+        @Override
         public Set<File> getAssetDirs() {
             return resourceDirs;
         }
 
+        @Override
         public void addAssetDir(File assetDir) {
             resourceDirs.add(assetDir);
         }
